﻿using System;
using System.Windows;
using Telerik.Windows.Controls.DataServices;
using Telerik.Windows.Controls;

namespace NorthwindServiceClient
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		private DateTime startTime;

		public MainWindow()
        {
            InitializeComponent();
        }

		private void OnDataSourceLoadingData(object sender, LoadingDataEventArgs e)
		{
			this.startTime = DateTime.Now;
			if (e.Query != null)
			{
				this.debugTextBox.Text = string.Format("--> Requesting {0}\r\n", e.Query.ToString());
			}
		}

		private void OnDataSourceLoadedData(object sender, LoadedDataEventArgs e)
		{
			if (e.HasError)
			{
				e.MarkErrorAsHandled();
				this.debugTextBox.Text = string.Format("<-- Server returned the following error: {0}\r\n"
					, e.Error);
			}
			else if (e.Cancelled)
			{
				this.debugTextBox.Text = string.Format("<-- Load operation was cancelled\r\n");
			}
			else
			{
				TimeSpan elapsedTime = DateTime.Now - this.startTime;
				this.debugTextBox.Text += string.Format("<-- Server replied in {0} ms\r\n"
					, elapsedTime.Milliseconds);
			}
		}

		private void OnRadGridViewAutoGeneratingColumn(object sender, GridViewAutoGeneratingColumnEventArgs e)
		{
			e.Column.ShowDistinctFilters = false;

			switch (e.Column.UniqueName)
			{
				case "Orders":
				case "CustomerDemographics":
					e.Cancel = true;
					break;
			}
		}
	}
}
